@@ -3,7 +3,7 @@ package Ormlette;
 use strict;
 use warnings;
 
-our $VERSION = 0.005;
+our $VERSION = 0.001000;
 
 use Carp;
 
@@ -20,14 +20,12 @@ sub init {
   my $self = bless {
     dbh         => $dbh,
     debug       => $params{debug} ? 1 : 0,
-    ignore_root => $params{ignore_root},
-    isa         => $params{isa},
     namespace   => $namespace,
     readonly    => $params{readonly} ? 1 : 0,
     tbl_names   => $tbl_names,
   }, $class;
 
-  $self->_build_root_pkg unless $self->{ignore_root};
+  $self->_build_root_pkg;
   $self->_build_table_pkg($_) for keys %$tbl_names;
 
   return $self;
@@ -49,16 +47,11 @@ sub _scan_tables {
   if ($params{tables}) {
     my %include = map { $_ => 1 } @{$params{tables}};
     @tables = grep { $include{$_} } @tables;
-  } elsif ($params{ignore_tables}) {
-    my %exclude = map { $_ => 1 } @{$params{ignore_tables}};
-    @tables = grep { !$exclude{$_} } @tables;
   }
 
   my %tbl_names;
   for (@tables) {
-    my $tbl = lc $_;
-    $tbl =~ s/__(.)/::\U$1/g;
-    my @words = split '_', $tbl;
+    my @words = split '_', lc $_;
     $tbl_names{$_} = $namespace . '::' . (join '', map { ucfirst } @words);
   }
 
@@ -110,7 +103,7 @@ sub _compile_pkg {
 sub _pkg_core {
   my ($self, $pkg_name) = @_;
 
-  my $core = <<"END_CODE";
+  return <<"END_CODE";
 package $pkg_name;
 
 use strict;
@@ -118,19 +111,6 @@ use warnings;
 
 use Carp;
 
-END_CODE
-
-  no strict 'refs';
-  if ($self->{isa} && !@{ $pkg_name . '::ISA' }) {
-    my $isa = $self->{isa};
-    $core .= <<"END_CODE";
-our \@ISA = '$isa';
-
-END_CODE
-  }
-  use strict 'refs';
-
-  $core .= <<"END_CODE";
 my \$_ormlette_dbh;
 
 sub dbh { \$_ormlette_dbh }
@@ -141,8 +121,6 @@ sub _ormlette_init {
 }
 
 END_CODE
-
-  return $core;
 }
 
 sub _root_methods {
@@ -187,7 +165,6 @@ sub iterate {
   my \$sth = \$class->dbh->prepare_cached(\$sql);
   \$sth->execute(\@_);
 
-  local \$_;
   while (\$_ = \$class->_ormlette_load_from_sth(\$sth)) {
     \$callback->();
   }
@@ -335,6 +312,7 @@ sub insert {
   my \$sth = \$self->dbh->prepare_cached(\$sql);
   \$sth->execute($insert_values);
   $handle_autoincrement
+  \$sth->finish;
   return \$self;
 }
 
@@ -358,8 +336,8 @@ sub update {
   my \$self = shift;
   my \$sql = 'UPDATE $tbl_name SET $update_fields WHERE $key_criteria';
   my \$sth = \$self->dbh->prepare_cached(\$sql);
-  my \$changed = \$sth->execute($insert_values, $key_values);
-  \$self->insert unless \$changed > 0;
+  \$sth->execute($insert_values, $key_values);
+  \$sth->finish;
 
   return \$self;
 }
@@ -398,22 +376,13 @@ sub new { my $class = shift; $class->_ormlette_new(@_); }
 ';
   }
 
-  if (@key) {
-    my $destroy_name =
-      $pkg_name->can('DESTROY') ? '_ormlette_DESTROY' : 'DESTROY';
-    $code .= "
-sub mark_dirty { \$_[0]->{_dirty} = 1 }
-sub mark_clean { \$_[0]->{_dirty} = 0 }
-sub dirty      { return \$_[0]->{_dirty} }
-
-sub $destroy_name { \$_[0]->update if \$_[0]->{_dirty} }"
-  }
-
   return $code;
 }
 
 1;
 
+
+
 =pod
 
 =head1 NAME
@@ -422,7 +391,7 @@ Ormlette - Light and fluffy object persistence
 
 =head1 VERSION
 
-version 0.005
+version 0.01
 
 =head1 SYNOPSIS
 
@@ -468,36 +437,6 @@ The C<debug> option will cause additional debugging information to be printed
 to STDERR as Ormlette does its initialization.  At this point, this consists
 solely of the generated source code for each package affected by Ormlette.
 
-=head3 isa
-
-Specifies that all Ormlette-generated classes should be made subclasses of
-the C<isa> package.  This is done by directly setting C<@ISA>, not via C<use
-base> or C<use parent>, so you are responsible for ensuring that the
-specified class is available to use as a parent.
-
-If Ormlette is adding to a class which already exists and already has a
-parent in C<@ISA>, the existing parent will be untouched and the C<isa> option
-will have no effect on that class.
-
-=head3 ignore_root
-
-Ormlette will normally inject a C<dbh> method into the base namespace of its
-generated code, providing access to the source database.  This is not always
-desirable.  In such cases, setting C<ignore_root> will prevent Ormlette from
-making any modifications to that package.
-
-=head3 ignore_tables
-
-Ormlette will normally generate classes corresponding to all tables found
-in the database.  If there are tables which should be skipped over, a
-reference to an array of table names to skip can be passed in the
-C<ignore_tables> parameter.
-
-If you prefer to list the tables to include rather than the tables to
-exclude, use C<tables>.  There should never be a reason to specify both
-C<tables> and C<ignore_tables>, but, if this is done, C<tables> will take
-precedence and C<ignore_tables> will be silently ignored.
-
 =head3 namespace
 
 By default, Ormlette will use the name of the package which calls C<init> as
@@ -516,23 +455,16 @@ If you only require Ormlette code to be generated for some of the tables in
 your database, providing a reference to an array of table names in the
 C<tables> parameter will cause all other tables to be ignored.
 
-If you prefer to list the tables to exclude rather than those to include,
-use C<ignore_tables>.
-
 =back
 
 =head2 dbh
 
 Returns the internal database handle used for database interaction.  Can be
-called on the core Ormlette object, the root namespace of its generated code
-(unless the C<ignore_root> option is set when calling C<init>), or any of the
-persistent classes generated in that namespace.
+called on the core Ormlette object, the root namespace of its generated code,
+or any of the persistent classes generated in that namespace.
 
 =head1 Root Namespace Methods
 
-If the C<ignore_root> option is set when calling C<init>, no methods will
-be generated in the root namespace.
-
 =head2 dbh
 
 Returns the database handle attached by Ormlette to the root namespace.  If
@@ -580,23 +512,6 @@ available for further use, including re-saving it to the database.
 This method will not be generated if C<readonly> is set.  The instance method
 variant will only be generated for tables which have a primary key.
 
-=head2 dirty
-
-Read-only flag indicating whether an object is "dirty" (i.e., has unsaved
-changes).  This flag is not maintained automatically; code using the object
-must use its C<mark_dirty> method to set the flag and C<mark_clean> to clear
-it.
-
-If an object is destroyed while dirty, a C<DESTROY> handler will automatically
-call its C<update> method to write changes to the database.  If the class
-already has a C<DESTROY> handler prior to Ormlette initialization, this check
-is instead placed into an C<_ormlette_DESTROY> method, which the other
-C<DESTROY> should call if autoupdate functionality is desired.
-
-The C<dirty> attribute, C<mark_dirty> and C<mark_clean> methods, and C<DESTROY>
-handler will not be generated if C<readonly> is set or for tables which do
-not have a primary key.
-
 =head2 insert
 
 Inserts the object into the database as a new record.  This method will fail if
@@ -617,14 +532,6 @@ loads one record into memory at a time, while C<select> loads all records at
 once, which may require unacceptable amounts of memory when dealing with larger
 data sets.
 
-=head2 mark_clean
-
-Clears an object's C<dirty> flag.
-
-=head2 mark_dirty
-
-Sets an object's C<dirty> flag.
-
 =head2 new
 
 Basic constructor which accepts a hash of values and blesses them into the
@@ -671,8 +578,8 @@ Returns the table name in which Ormlette stores this class's data.
 
 =head2 update
 
-Updates the object's existing database record.  This method will implicitly
-call C<insert> if the object does not already exist in the database.
+Updates the object's existing database record.  This method will fail if the
+object does not already exist in the database.
 
 This method will not be generated if C<readonly> is set or for tables which
 do not have a primary key.
@@ -714,13 +621,14 @@ Dave Sherohman <dsheroh@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2012 by Dave Sherohman.
+This software is copyright (c) 2010 by Dave Sherohman.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
 
+
 __END__
 
 # ABSTRACT: Light and fluffy object persistence
